.. Kamaki documentation master file, created by
   sphinx-quickstart on Tue Nov 29 15:15:50 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
 
Kamaki project documentation
============================

.. image:: /images/kamaki-logo.png

./kamaki is a multipurpose, interactive command-line tool and also a client
development API for managing clouds.

As a development library, it implements the OpenStack APIs,
along with the custom extensions introduced by Synnefo
(`Synnefo IaaS <http://www.synnefo.org/>`_).

./kamaki is open source and released under a 2-clause BSD License.


Contents:
*********

.. toctree::
   :maxdepth: 2
   :numbered:
   :glob:
   
   overview
   installation
   setup
   usage
   commands
   examples
   devguide


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
